@@ -1,16 +1,18 @@
 import sqlalchemy as sa
+from .builders import ImproperlyConfigured
 from .manager import translation_manager, TranslationManager
 from .translatable import Translatable
 
 
 __all__ = (
+    ImproperlyConfigured,
     Translatable,
     TranslationManager,
     translation_manager
 )
 
 
-__version__ = '0.6.11'
+__version__ = '0.6.12'
 
 
 def make_translatable(
